summaryrefslogtreecommitdiffstats
path: root/gearman
diff options
context:
space:
mode:
authorBjörn Geiger2011-08-16 17:07:20 +0200
committerBjörn Geiger2011-08-16 17:07:20 +0200
commit18811cc24ea09cee7811604c479c99c62f60355c (patch)
treea3e23dc622b03d24f3c3caa9a0836bff95f8796e /gearman
parentreboot changes (diff)
downloadpoolctrl-18811cc24ea09cee7811604c479c99c62f60355c.tar.gz
poolctrl-18811cc24ea09cee7811604c479c99c62f60355c.tar.xz
poolctrl-18811cc24ea09cee7811604c479c99c62f60355c.zip
minor
Diffstat (limited to 'gearman')
-rw-r--r--gearman/controllerWorker/ControllerWorker/Boot.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/gearman/controllerWorker/ControllerWorker/Boot.java b/gearman/controllerWorker/ControllerWorker/Boot.java
index 2fe7879..7181cbf 100644
--- a/gearman/controllerWorker/ControllerWorker/Boot.java
+++ b/gearman/controllerWorker/ControllerWorker/Boot.java
@@ -658,12 +658,12 @@ public class Boot extends Thread {
} else {
System.out
.println(ipAddress
- + " Cannot send the ping after restart message.");
+ + " Cannot send the ping after shutdown message.");
this.errors
.put(clientID,
- "Sending the ping after restart message has been failed.");
+ "Sending the ping after shutdown message has been failed.");
/*
* sending the ping after restart message
* has been failed
*/
status.put(clientID, 29);
@@ -658,12 +658,12 @@ public class Boot extends Thread {
/*
- * sending the ping after restart message
+ * sending the ping after shutdown message
* has been failed
*/